@@ -1,4 +1,5 @@
 library("testthat")
-library("XML")
 require("jsonlite", warn.conflicts = FALSE, quietly = TRUE)
+library("xml2")
+
 test_check("rbhl")
