@@ -1,11 +1,10 @@
-context("bhl_gettitlemetadata")
-
 test_that("bhl_gettitlemetadata works", {
   skip_on_cran()
-
-  tt <- bhl_gettitlemetadata(1726)
-  vv <- bhl_gettitlemetadata(1726, as='xml')
-  zz <- bhl_gettitlemetadata(1726, as='json')
+  vcr::use_cassette("bhl_gettitlemetadata", {
+    tt <- bhl_gettitlemetadata(1726)
+    vv <- bhl_gettitlemetadata(1726, as='xml')
+    zz <- bhl_gettitlemetadata(1726, as='json')
+  })
 
   # the correct classes
   expect_is(tt, "list")
